@@ -4,14 +4,14 @@ use warnings;
 use 5.006;
 
 package LWP::ConsoleLogger;
-$LWP::ConsoleLogger::VERSION = '0.000025';
+$LWP::ConsoleLogger::VERSION = '0.000026';
 use Data::Printer { end_separator => 1, hash_separator => ' => ' };
 use DateTime qw();
 use HTML::Restrict qw();
 use HTTP::Body;
 use HTTP::CookieMonster qw();
 use JSON::MaybeXS qw( decode_json );
-use List::AllUtils qw( none );
+use List::AllUtils qw( apply none );
 use Log::Dispatch qw();
 use Moo;
 use MooX::StrictConstructor;
@@ -283,9 +283,9 @@ sub _get_content {
     my $content = $ua->decoded_content;
     return unless $content;
 
-    my ( $type, $subtype ) = parse_mime_type($content_type);
+    my ( $type, $subtype ) = apply { lc $_ } parse_mime_type($content_type);
     if (   ( $type ne 'text' )
-        && ( none { $_ eq $subtype } ( 'html', 'json', 'xml' ) )
+        && ( none { $_ eq $subtype } ( 'javascript', 'html', 'json', 'xml' ) )
         && $subtype !~ m{$json_regex} ) {
         $content = $self->_redaction_message($content_type);
     }
@@ -354,14 +354,12 @@ sub _parse_body {
         return;
     }
 
-    my ( $type, $subtype ) = parse_mime_type($content_type);
+    my ( $type, $subtype ) = apply { lc $_ } parse_mime_type($content_type);
     unless ($subtype) {
         $t->row($content);
         return;
     }
 
-    $subtype = lc $subtype;
-
     if ( $subtype eq 'html' ) {
         $content = $self->html_restrict->process($content);
         $content =~ s{\s+}{ }g;
@@ -383,6 +381,14 @@ sub _parse_body {
         }
         catch { $t->row("Error parsing JSON: $_") };
     }
+    elsif ( $type && $type eq 'application' && $subtype eq 'javascript' ) {
+
+        # clean it up a bit, and print some of it
+        $content =~ s{^\s*}{}mg;
+        if ( length $content > 253 ) {
+            $content = substr( $content, 0, 252 ) . '...';
+        }
+    }
     elsif ( !$type || $type ne 'text' ) {
 
         # Avoid things like dumping gzipped content to the screen
@@ -441,7 +447,7 @@ LWP::ConsoleLogger - LWP tracing and debugging
 
 =head1 VERSION
 
-version 0.000025
+version 0.000026
 
 =head1 SYNOPSIS
 
